@@ -50,6 +50,12 @@ class Migrate(base.BaseAction):
     source and the destination compute hostname (list of available compute
     hosts is returned by this command: ``nova service-list --binary
     nova-compute``).
+
+    .. note::
+
+        Nova API version must be 2.56 or above if `destination_node` parameter
+        is given.
+
     """
 
     # input parameters constants
@@ -81,6 +87,10 @@ class Migrate(base.BaseAction):
                                 "([a-fA-F0-9]){4}-([a-fA-F0-9]){4}-"
                                 "([a-fA-F0-9]){12}$")
                 },
+                'resource_name': {
+                    'type': 'string',
+                    "minlength": 1
+                },
                 'source_node': {
                     'type': 'string',
                     "minLength": 1
@@ -113,8 +123,10 @@ class Migrate(base.BaseAction):
                                                 dest_hostname=destination)
         except nova_helper.nvexceptions.ClientException as e:
             LOG.debug("Nova client exception occurred while live "
-                      "migrating instance %s.Exception: %s" %
-                      (self.instance_uuid, e))
+                      "migrating instance "
+                      "%(instance)s.Exception: %(exception)s",
+                      {'instance': self.instance_uuid, 'exception': e})
+
         except Exception as e:
             LOG.exception(e)
             LOG.critical("Unexpected error occurred. Migration failed for "
@@ -174,7 +186,7 @@ class Migrate(base.BaseAction):
         return self.migrate(destination=self.destination_node)
 
     def revert(self):
-        return self.migrate(destination=self.source_node)
+        LOG.info('Migrate action do not revert!')
 
     def abort(self):
         nova = nova_helper.NovaHelper(osc=self.osc)
