@@ -48,7 +48,7 @@ from watcher.common import context
 from watcher.common import exception
 from watcher.common.loader import loadable
 from watcher.common import utils
-from watcher.datasource import manager as ds_manager
+from watcher.decision_engine.datasources import manager as ds_manager
 from watcher.decision_engine.loading import default as loading
 from watcher.decision_engine.model.collector import manager
 from watcher.decision_engine.solution import default
@@ -130,6 +130,10 @@ class BaseStrategy(loadable.Loadable):
     """
 
     DATASOURCE_METRICS = []
+    """Contains all metrics the strategy requires from a datasource to properly
+    execute"""
+
+    MIGRATION = "migrate"
 
     def __init__(self, config, osc=None):
         """Constructor: the signature should be identical within the subclasses
@@ -157,6 +161,7 @@ class BaseStrategy(loadable.Loadable):
         self._input_parameters = utils.Struct()
         self._audit_scope = None
         self._datasource_backend = None
+        self._planner = 'weight'
 
     @classmethod
     @abc.abstractmethod
@@ -197,7 +202,18 @@ class BaseStrategy(loadable.Loadable):
         :return: A list of configuration options relative to this Loadable
         :rtype: list of :class:`oslo_config.cfg.Opt` instances
         """
-        return []
+
+        datasources_ops = list(ds_manager.DataSourceManager.metric_map.keys())
+
+        return [
+            cfg.ListOpt(
+                "datasources",
+                help="Datasources to use in order to query the needed metrics."
+                     " This option overrides the global preference."
+                     " options: {0}".format(datasources_ops),
+                item_type=cfg.types.String(choices=datasources_ops),
+                default=None)
+        ]
 
     @abc.abstractmethod
     def pre_execute(self):
@@ -208,9 +224,12 @@ class BaseStrategy(loadable.Loadable):
         raise NotImplementedError()
 
     @abc.abstractmethod
-    def do_execute(self):
+    def do_execute(self, audit=None):
         """Strategy execution phase
 
+        :param audit: An Audit instance
+        :type audit: :py:class:`~.Audit` instance
+
         This phase is where you should put the main logic of your strategy.
         """
         raise NotImplementedError()
@@ -230,7 +249,7 @@ class BaseStrategy(loadable.Loadable):
          should perform.
         """
 
-        LOG.info("Initializing " + self.get_display_name() + " Strategy")
+        LOG.info("Initializing " + self.get_display_name())
 
         if not self.compute_model:
             raise exception.ClusterStateNotDefined()
@@ -240,14 +259,16 @@ class BaseStrategy(loadable.Loadable):
 
         LOG.debug(self.compute_model.to_string())
 
-    def execute(self):
+    def execute(self, audit=None):
         """Execute a strategy
 
+        :param audit: An Audit instance
+        :type audit: :py:class:`~.Audit` instance
         :return: A computed solution (via a placement algorithm)
         :rtype: :py:class:`~.BaseSolution` instance
         """
         self.pre_execute()
-        self.do_execute()
+        self.do_execute(audit=audit)
         self.post_execute()
 
         self.solution.compute_global_efficacy()
@@ -341,8 +362,15 @@ class BaseStrategy(loadable.Loadable):
     @property
     def datasource_backend(self):
         if not self._datasource_backend:
+
+            # Load the global preferred datasources order but override it
+            # if the strategy has a specific datasources config
+            datasources = CONF.watcher_datasources
+            if self.config.datasources:
+                datasources = self.config
+
             self._datasource_backend = ds_manager.DataSourceManager(
-                config=self.config,
+                config=datasources,
                 osc=self.osc
             ).get_backend(self.DATASOURCE_METRICS)
         return self._datasource_backend
@@ -405,6 +433,14 @@ class BaseStrategy(loadable.Loadable):
     def state_collector(self, s):
         self._cluster_state_collector = s
 
+    @property
+    def planner(self):
+        return self._planner
+
+    @planner.setter
+    def planner(self, s):
+        self._planner = s
+
     def filter_instances_by_audit_tag(self, instances):
         if not self.config.check_optimize_metadata:
             return instances
@@ -421,6 +457,19 @@ class BaseStrategy(loadable.Loadable):
                 instances_to_migrate.append(instance)
         return instances_to_migrate
 
+    def add_action_migrate(self,
+                           instance,
+                           migration_type,
+                           source_node,
+                           destination_node):
+        parameters = {'migration_type': migration_type,
+                      'source_node': source_node.hostname,
+                      'destination_node': destination_node.hostname,
+                      'resource_name': instance.name}
+        self.solution.add_action(action_type=self.MIGRATION,
+                                 resource_id=instance.uuid,
+                                 input_parameters=parameters)
+
 
 @six.add_metaclass(abc.ABCMeta)
 class DummyBaseStrategy(BaseStrategy):
@@ -429,6 +478,12 @@ class DummyBaseStrategy(BaseStrategy):
     def get_goal_name(cls):
         return "dummy"
 
+    @classmethod
+    def get_config_opts(cls):
+        """Override base class config options as do not use datasource """
+
+        return []
+
 
 @six.add_metaclass(abc.ABCMeta)
 class UnclassifiedStrategy(BaseStrategy):
@@ -466,6 +521,11 @@ class ThermalOptimizationBaseStrategy(BaseStrategy):
 @six.add_metaclass(abc.ABCMeta)
 class WorkloadStabilizationBaseStrategy(BaseStrategy):
 
+    def __init__(self, *args, **kwargs):
+        super(WorkloadStabilizationBaseStrategy, self
+              ).__init__(*args, **kwargs)
+        self._planner = 'workload_stabilization'
+
     @classmethod
     def get_goal_name(cls):
         return "workload_balancing"
@@ -486,6 +546,12 @@ class SavingEnergyBaseStrategy(BaseStrategy):
     def get_goal_name(cls):
         return "saving_energy"
 
+    @classmethod
+    def get_config_opts(cls):
+        """Override base class config options as do not use datasource """
+
+        return []
+
 
 @six.add_metaclass(abc.ABCMeta)
 class ZoneMigrationBaseStrategy(BaseStrategy):
@@ -494,6 +560,12 @@ class ZoneMigrationBaseStrategy(BaseStrategy):
     def get_goal_name(cls):
         return "hardware_maintenance"
 
+    @classmethod
+    def get_config_opts(cls):
+        """Override base class config options as do not use datasource """
+
+        return []
+
 
 @six.add_metaclass(abc.ABCMeta)
 class HostMaintenanceBaseStrategy(BaseStrategy):
@@ -503,3 +575,9 @@ class HostMaintenanceBaseStrategy(BaseStrategy):
     @classmethod
     def get_goal_name(cls):
         return "cluster_maintaining"
+
+    @classmethod
+    def get_config_opts(cls):
+        """Override base class config options as do not use datasource """
+
+        return []
