@@ -11,6 +11,7 @@
 #    limitations under the License.
 
 import datetime
+from dateutil import tz
 import itertools
 import mock
 
@@ -37,13 +38,16 @@ def post_get_test_audit(**kw):
     audit_template = db_utils.get_test_audit_template()
     goal = db_utils.get_test_goal()
     del_keys = ['goal_id', 'strategy_id']
+    del_keys.extend(kw.get('params_to_exclude', []))
     add_keys = {'audit_template_uuid': audit_template['uuid'],
                 'goal': goal['uuid'],
                 }
-    for k in del_keys:
-        del audit[k]
+    if kw.get('use_named_goal'):
+        add_keys['goal'] = 'TEST'
     for k in add_keys:
         audit[k] = kw.get(k, add_keys[k])
+    for k in del_keys:
+        del audit[k]
     return audit
 
 
@@ -380,9 +384,9 @@ class TestPatchStateTransitionDenied(api_base.FunctionalTest):
         )
         for original_state, new_state
         in list(itertools.product(STATES, STATES))
-        if original_state != new_state
-        and {"original_state": original_state,
-             "new_state": new_state} not in ALLOWED_TRANSITIONS
+        if original_state != new_state and
+        {"original_state": original_state,
+         "new_state": new_state} not in ALLOWED_TRANSITIONS
     ]
 
     def setUp(self):
@@ -491,13 +495,10 @@ class TestPost(api_base.FunctionalTest):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
 
-        audit_dict = post_get_test_audit(state=objects.audit.State.PENDING)
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            state=objects.audit.State.PENDING,
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
 
         response = self.post_json('/audits', audit_dict)
         self.assertEqual('application/json', response.content_type)
@@ -530,18 +531,78 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual('application/json', response.content_type)
         self.assertTrue(response.json['error_message'])
 
+    @mock.patch('oslo_utils.timeutils.utcnow')
+    def test_create_audit_with_at_uuid_and_goal_specified(self, mock_utcnow):
+        test_time = datetime.datetime(2000, 1, 1, 0, 0)
+        mock_utcnow.return_value = test_time
+
+        audit_dict = post_get_test_audit(
+            state=objects.audit.State.PENDING,
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname'])
+
+        response = self.post_json('/audits', audit_dict, expect_errors=True)
+        self.assertEqual(400, response.status_int)
+        self.assertEqual('application/json', response.content_type)
+        self.assertTrue(response.json['error_message'])
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_audit_with_goal(self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname',
+                               'audit_template_uuid'])
+
+        response = self.post_json('/audits', audit_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertEqual(objects.audit.State.PENDING,
+                         response.json['state'])
+        self.assertTrue(utils.is_uuid_like(response.json['uuid']))
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_audit_with_goal_without_strategy(self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname',
+                               'audit_template_uuid', 'strategy'])
+
+        response = self.post_json('/audits', audit_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertEqual(objects.audit.State.PENDING,
+                         response.json['state'])
+        self.assertTrue(utils.is_uuid_like(response.json['uuid']))
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_audit_with_named_goal(self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname',
+                               'audit_template_uuid'],
+            use_named_goal=True)
+
+        response = self.post_json('/audits', audit_dict)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertEqual(objects.audit.State.PENDING,
+                         response.json['state'])
+        self.assertTrue(utils.is_uuid_like(response.json['uuid']))
+
     @mock.patch('oslo_utils.timeutils.utcnow')
     def test_create_audit_invalid_audit_template_uuid(self, mock_utcnow):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         # Make the audit template UUID some garbage value
         audit_dict['audit_template_uuid'] = (
             '01234567-8910-1112-1314-151617181920')
@@ -558,14 +619,12 @@ class TestPost(api_base.FunctionalTest):
     def test_create_audit_doesnt_contain_id(self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit(state=objects.audit.State.PENDING)
+        audit_dict = post_get_test_audit(
+            state=objects.audit.State.PENDING,
+            params_to_exclude=['uuid', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         state = audit_dict['state']
-        del audit_dict['uuid']
         del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
         with mock.patch.object(self.dbapi, 'create_audit',
                                wraps=self.dbapi.create_audit) as cn_mock:
             response = self.post_json('/audits', audit_dict)
@@ -578,13 +637,9 @@ class TestPost(api_base.FunctionalTest):
     def test_create_audit_generate_uuid(self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
 
         response = self.post_json('/audits', audit_dict)
         self.assertEqual('application/json', response.content_type)
@@ -597,12 +652,9 @@ class TestPost(api_base.FunctionalTest):
     def test_create_continuous_audit_with_interval(self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = '1200'
 
@@ -619,12 +671,9 @@ class TestPost(api_base.FunctionalTest):
                                                         mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = '* * * * *'
 
@@ -641,12 +690,9 @@ class TestPost(api_base.FunctionalTest):
                                                          mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
         audit_dict['interval'] = 'zxc'
 
@@ -662,14 +708,10 @@ class TestPost(api_base.FunctionalTest):
     def test_create_continuous_audit_without_period(self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual(400, response.status_int)
@@ -683,13 +725,10 @@ class TestPost(api_base.FunctionalTest):
     def test_create_oneshot_audit_with_period(self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
 
-        audit_dict = post_get_test_audit()
-        del audit_dict['uuid']
-        del audit_dict['state']
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         audit_dict['audit_type'] = objects.audit.AuditType.ONESHOT.value
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual(400, response.status_int)
@@ -701,13 +740,10 @@ class TestPost(api_base.FunctionalTest):
     def test_create_audit_trigger_decision_engine(self):
         with mock.patch.object(deapi.DecisionEngineAPI,
                                'trigger_audit') as de_mock:
-            audit_dict = post_get_test_audit(state=objects.audit.State.PENDING)
-            del audit_dict['uuid']
-            del audit_dict['state']
-            del audit_dict['interval']
-            del audit_dict['scope']
-            del audit_dict['next_run_time']
-            del audit_dict['hostname']
+            audit_dict = post_get_test_audit(
+                state=objects.audit.State.PENDING,
+                params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                                   'next_run_time', 'hostname', 'goal'])
             response = self.post_json('/audits', audit_dict)
             de_mock.assert_called_once_with(mock.ANY, response.json['uuid'])
 
@@ -726,13 +762,10 @@ class TestPost(api_base.FunctionalTest):
     def test_create_audit_parameters_no_predefined_strategy(
             self, mock_trigger_audit):
         mock_trigger_audit.return_value = mock.ANY
-        audit_dict = post_get_test_audit(parameters={'name': 'Tom'})
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            parameters={'name': 'Tom'},
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
 
         response = self.post_json('/audits', audit_dict, expect_errors=True)
         self.assertEqual('application/json', response.content_type)
@@ -831,16 +864,13 @@ class TestPost(api_base.FunctionalTest):
         test_time = datetime.datetime(2000, 1, 1, 0, 0)
         mock_utcnow.return_value = test_time
 
-        audit_dict = post_get_test_audit()
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         normal_name = 'this audit name is just for test'
         # long_name length exceeds 63 characters
         long_name = normal_name + audit_dict['uuid']
         del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['interval']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
 
         audit_dict['name'] = normal_name
         response = self.post_json('/audits', audit_dict)
@@ -854,6 +884,105 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual(201, response.status_int)
         self.assertNotEqual(long_name, response.json['name'])
 
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_continuous_audit_with_start_end_time(
+            self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+        start_time = datetime.datetime(2018, 3, 1, 0, 0)
+        end_time = datetime.datetime(2018, 4, 1, 0, 0)
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal']
+        )
+        audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
+        audit_dict['interval'] = '1200'
+        audit_dict['start_time'] = str(start_time)
+        audit_dict['end_time'] = str(end_time)
+
+        response = self.post_json(
+            '/audits',
+            audit_dict,
+            headers={'OpenStack-API-Version': 'infra-optim 1.1'})
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertEqual(objects.audit.State.PENDING,
+                         response.json['state'])
+        self.assertEqual(audit_dict['interval'], response.json['interval'])
+        self.assertTrue(utils.is_uuid_like(response.json['uuid']))
+        return_start_time = timeutils.parse_isotime(
+            response.json['start_time'])
+        return_end_time = timeutils.parse_isotime(
+            response.json['end_time'])
+        iso_start_time = start_time.replace(
+            tzinfo=tz.tzlocal()).astimezone(tz.tzutc())
+        iso_end_time = end_time.replace(
+            tzinfo=tz.tzlocal()).astimezone(tz.tzutc())
+
+        self.assertEqual(iso_start_time, return_start_time)
+        self.assertEqual(iso_end_time, return_end_time)
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_continuous_audit_with_start_end_time_incompatible_version(
+            self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+        start_time = datetime.datetime(2018, 3, 1, 0, 0)
+        end_time = datetime.datetime(2018, 4, 1, 0, 0)
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal']
+        )
+        audit_dict['audit_type'] = objects.audit.AuditType.CONTINUOUS.value
+        audit_dict['interval'] = '1200'
+        audit_dict['start_time'] = str(start_time)
+        audit_dict['end_time'] = str(end_time)
+
+        response = self.post_json(
+            '/audits',
+            audit_dict,
+            headers={'OpenStack-API-Version': 'infra-optim 1.0'},
+            expect_errors=True)
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(406, response.status_int)
+        expected_error_msg = 'Request not acceptable.'
+        self.assertTrue(response.json['error_message'])
+        self.assertIn(expected_error_msg, response.json['error_message'])
+        assert not mock_trigger_audit.called
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_audit_with_force_false(self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
+
+        response = self.post_json(
+            '/audits',
+            audit_dict,
+            headers={'OpenStack-API-Version': 'infra-optim 1.2'})
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertFalse(response.json['force'])
+
+    @mock.patch.object(deapi.DecisionEngineAPI, 'trigger_audit')
+    def test_create_audit_with_force_true(self, mock_trigger_audit):
+        mock_trigger_audit.return_value = mock.ANY
+
+        audit_dict = post_get_test_audit(
+            params_to_exclude=['uuid', 'state', 'interval', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
+
+        audit_dict['force'] = True
+        response = self.post_json(
+            '/audits',
+            audit_dict,
+            headers={'OpenStack-API-Version': 'infra-optim 1.2'})
+        self.assertEqual('application/json', response.content_type)
+        self.assertEqual(201, response.status_int)
+        self.assertTrue(response.json['force'])
+
 
 class TestDelete(api_base.FunctionalTest):
 
@@ -962,12 +1091,10 @@ class TestAuditPolicyEnforcement(api_base.FunctionalTest):
              'op': 'replace'}], expect_errors=True)
 
     def test_policy_disallow_create(self):
-        audit_dict = post_get_test_audit(state=objects.audit.State.PENDING)
-        del audit_dict['uuid']
-        del audit_dict['state']
-        del audit_dict['scope']
-        del audit_dict['next_run_time']
-        del audit_dict['hostname']
+        audit_dict = post_get_test_audit(
+            state=objects.audit.State.PENDING,
+            params_to_exclude=['uuid', 'state', 'scope',
+                               'next_run_time', 'hostname', 'goal'])
         self._common_policy_check(
             "audit:create", self.post_json, '/audits', audit_dict,
             expect_errors=True)
