@@ -13,12 +13,13 @@
 from ceilometerclient import client as ceclient
 import ceilometerclient.v2.client as ceclient_v2
 from cinderclient import client as ciclient
-from cinderclient.v1 import client as ciclient_v1
+from cinderclient.v3 import client as ciclient_v3
 from glanceclient import client as glclient
 from gnocchiclient import client as gnclient
 from gnocchiclient.v1 import client as gnclient_v1
 from ironicclient import client as irclient
 from ironicclient.v1 import client as irclient_v1
+from keystoneauth1 import adapter as ka_adapter
 from keystoneauth1 import loading as ka_loading
 import mock
 from monascaclient import client as monclient
@@ -45,7 +46,7 @@ class TestClients(base.TestCase):
         # ka_loading.load_auth_from_conf_options(CONF, _AUTH_CONF_GROUP)
         # ka_loading.load_session_from_conf_options(CONF, _AUTH_CONF_GROUP)
         # CONF.set_override(
-        #     'auth-url', 'http://server.ip:35357', group=_AUTH_CONF_GROUP)
+        #     'auth-url', 'http://server.ip:5000', group=_AUTH_CONF_GROUP)
 
         # If we don't clean up the _AUTH_CONF_GROUP conf options, then other
         # tests that run after this one will fail, complaining about required
@@ -68,7 +69,7 @@ class TestClients(base.TestCase):
 
         expected = {'username': 'foousername',
                     'password': 'foopassword',
-                    'auth_url': 'http://server.ip:35357',
+                    'auth_url': 'http://server.ip:5000',
                     'cafile': None,
                     'certfile': None,
                     'keyfile': None,
@@ -99,7 +100,7 @@ class TestClients(base.TestCase):
 
         expected = {'username': 'foousername',
                     'password': 'foopassword',
-                    'auth_url': 'http://server.ip:35357',
+                    'auth_url': 'http://server.ip:5000',
                     'user_domain_id': 'foouserdomainid',
                     'project_domain_id': 'fooprojdomainid'}
 
@@ -120,15 +121,24 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.nova_client.api_version,
             endpoint_type=CONF.nova_client.endpoint_type,
+            region_name=CONF.nova_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_nova_diff_vers(self, mock_session):
-        CONF.set_override('api_version', '2.3', group='nova_client')
+        CONF.set_override('api_version', '2.60', group='nova_client')
         osc = clients.OpenStackClients()
         osc._nova = None
         osc.nova()
-        self.assertEqual('2.3', osc.nova().api_version.get_string())
+        self.assertEqual('2.60', osc.nova().api_version.get_string())
+
+    @mock.patch.object(clients.OpenStackClients, 'session')
+    def test_clients_nova_bad_min_version(self, mock_session):
+        CONF.set_override('api_version', '2.47', group='nova_client')
+        osc = clients.OpenStackClients()
+        osc._nova = None
+        ex = self.assertRaises(ValueError, osc.nova)
+        self.assertIn('Invalid nova_client.api_version 2.47', str(ex))
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_nova_diff_endpoint(self, mock_session):
@@ -155,6 +165,7 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.glance_client.api_version,
             interface=CONF.glance_client.endpoint_type,
+            region_name=CONF.glance_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -191,7 +202,8 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.gnocchi_client.api_version,
             adapter_options={
-                "interface": CONF.gnocchi_client.endpoint_type},
+                "interface": CONF.gnocchi_client.endpoint_type,
+                "region_name": CONF.gnocchi_client.region_name},
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -229,15 +241,16 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.cinder_client.api_version,
             endpoint_type=CONF.cinder_client.endpoint_type,
+            region_name=CONF.cinder_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_cinder_diff_vers(self, mock_session):
-        CONF.set_override('api_version', '1', group='cinder_client')
+        CONF.set_override('api_version', '3', group='cinder_client')
         osc = clients.OpenStackClients()
         osc._cinder = None
         osc.cinder()
-        self.assertEqual(ciclient_v1.Client, type(osc.cinder()))
+        self.assertEqual(ciclient_v3.Client, type(osc.cinder()))
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_cinder_diff_endpoint(self, mock_session):
@@ -266,6 +279,7 @@ class TestClients(base.TestCase):
             CONF.ceilometer_client.api_version,
             None,
             endpoint_type=CONF.ceilometer_client.endpoint_type,
+            region_name=CONF.ceilometer_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -314,6 +328,7 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.neutron_client.api_version,
             endpoint_type=CONF.neutron_client.endpoint_type,
+            region_name=CONF.neutron_client.region_name,
             session=mock_session)
 
     @mock.patch.object(clients.OpenStackClients, 'session')
@@ -360,7 +375,7 @@ class TestClients(base.TestCase):
         mock_call.assert_called_once_with(
             CONF.monasca_client.api_version,
             'test_endpoint',
-            auth_url='http://server.ip:35357', cert_file=None, insecure=False,
+            auth_url='http://server.ip:5000', cert_file=None, insecure=False,
             key_file=None, keystone_timeout=None, os_cacert=None,
             password='foopassword', service_type='monitoring',
             token='test_token', username='foousername')
@@ -401,13 +416,7 @@ class TestClients(base.TestCase):
         osc = clients.OpenStackClients()
         osc._ironic = None
         osc.ironic()
-        mock_call.assert_called_once_with(
-            CONF.ironic_client.api_version,
-            ironic_url,
-            max_retries=None,
-            os_ironic_api_version=None,
-            retry_interval=None,
-            session=mock_session)
+        mock_call.assert_called()
 
     @mock.patch.object(clients.OpenStackClients, 'session')
     def test_clients_ironic_diff_vers(self, mock_session):
@@ -426,7 +435,7 @@ class TestClients(base.TestCase):
         osc = clients.OpenStackClients()
         osc._ironic = None
         osc.ironic()
-        mock_session.get_endpoint.assert_called_once_with(
+        mock_session.get_endpoint.assert_called_with(
             interface='publicURL',
             region_name=None,
             service_type='baremetal')
@@ -449,3 +458,17 @@ class TestClients(base.TestCase):
         ironic = osc.ironic()
         ironic_cached = osc.ironic()
         self.assertEqual(ironic, ironic_cached)
+
+    @mock.patch.object(ka_adapter, 'Adapter')
+    @mock.patch.object(clients.OpenStackClients, 'session')
+    def test_clients_placement(self, mock_session, mock_call):
+        osc = clients.OpenStackClients()
+        osc.placement()
+        headers = {'accept': 'application/json'}
+        mock_call.assert_called_once_with(
+            session=mock_session,
+            service_type='placement',
+            default_microversion=CONF.placement_client.api_version,
+            interface=CONF.placement_client.interface,
+            region_name=CONF.placement_client.region_name,
+            additional_headers=headers)
