@@ -16,6 +16,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import mock
 import os
 
 from oslo_utils import uuidutils
@@ -63,6 +64,38 @@ class TestModel(base.TestCase):
         model = model_root.ModelRoot.from_xml(struct_str)
         self.assertEqual(expected_model.to_string(), model.to_string())
 
+    @mock.patch.object(model_root.ModelRoot, 'get_all_compute_nodes')
+    @mock.patch.object(model_root.ModelRoot, 'get_node_instances')
+    def test_get_model_to_list(self, mock_instances, mock_nodes):
+        fake_compute_node = mock.MagicMock(
+            uuid='fake_node_uuid',
+            fields=['uuid'])
+        fake_instance = mock.MagicMock(
+            uuid='fake_instance_uuid',
+            fields=['uuid'])
+
+        mock_nodes.return_value = {'fake_node_uuid': fake_compute_node}
+        mock_instances.return_value = [fake_instance]
+
+        expected_keys = ['server_uuid', 'node_uuid']
+
+        result = model_root.ModelRoot().to_list()
+        self.assertEqual(1, len(result))
+
+        result_keys = result[0].keys()
+        self.assertEqual(sorted(expected_keys), sorted(result_keys))
+
+        # test compute node has no instance
+        mock_instances.return_value = []
+
+        expected_keys = ['node_uuid']
+
+        result = model_root.ModelRoot().to_list()
+        self.assertEqual(1, len(result))
+
+        result_keys = result[0].keys()
+        self.assertEqual(expected_keys, list(result_keys))
+
     def test_get_node_by_instance_uuid(self):
         model = model_root.ModelRoot()
         uuid_ = "{0}".format(uuidutils.generate_uuid())
@@ -122,6 +155,32 @@ class TestModel(base.TestCase):
         node.state = element.ServiceState.OFFLINE.value
         self.assertIn(node.state, [el.value for el in element.ServiceState])
 
+    def test_get_node_by_name(self):
+        model = model_root.ModelRoot()
+        uuid_ = "{0}".format(uuidutils.generate_uuid())
+        name = 'test_node'
+        node = element.ComputeNode()
+        node.uuid = uuid_
+        node.hostname = name
+        model.add_node(node)
+        compute_node = model.get_node_by_name(name)
+        model.assert_node(compute_node)
+        self.assertEqual(name, compute_node['hostname'])
+        self.assertEqual(uuid_, compute_node['uuid'])
+
+    def test_node_from_name_raise(self):
+        model = model_root.ModelRoot()
+        uuid_ = "{0}".format(uuidutils.generate_uuid())
+        name = 'test_node'
+        node = element.ComputeNode()
+        node.uuid = uuid_
+        node.hostname = name
+        model.add_node(node)
+
+        fake_name = 'fake_node'
+        self.assertRaises(exception.ComputeNodeNotFound,
+                          model.get_node_by_name, fake_name)
+
     def test_node_from_uuid_raise(self):
         model = model_root.ModelRoot()
         uuid_ = "{0}".format(uuidutils.generate_uuid())
@@ -167,6 +226,38 @@ class TestModel(base.TestCase):
         self.assertRaises(exception.IllegalArgumentException,
                           model.assert_instance, "valeur_qcq")
 
+    def test_get_node_instances(self):
+        fake_cluster = faker_cluster_state.FakerModelCollector()
+        model = fake_cluster.generate_scenario_1()
+        node = element.ComputeNode(uuid="Node_0")
+        instance0 = model.get_instance_by_uuid("INSTANCE_0")
+        instance1 = model.get_instance_by_uuid("INSTANCE_1")
+        instances = model.get_node_instances(node)
+
+        self.assertEqual(2, len(instances))
+        self.assertIn(instance0, instances)
+        self.assertIn(instance1, instances)
+
+    def test_get_node_used_resources(self):
+        fake_cluster = faker_cluster_state.FakerModelCollector()
+        model = fake_cluster.generate_scenario_1()
+        node = element.ComputeNode(uuid="Node_0")
+        resources_used = model.get_node_used_resources(node)
+
+        self.assertEqual(20, resources_used.get('vcpu'))
+        self.assertEqual(4, resources_used.get('memory'))
+        self.assertEqual(40, resources_used.get('disk'))
+
+    def test_get_node_free_resources(self):
+        fake_cluster = faker_cluster_state.FakerModelCollector()
+        model = fake_cluster.generate_scenario_1()
+        node = model.get_node_by_uuid("Node_0")
+        resources_free = model.get_node_free_resources(node)
+
+        self.assertEqual(20, resources_free.get('vcpu'))
+        self.assertEqual(128, resources_free.get('memory'))
+        self.assertEqual(210, resources_free.get('disk'))
+
 
 class TestStorageModel(base.TestCase):
 
