@@ -24,9 +24,6 @@ from watcher.tests import base
 
 class TestDecisionEngineAPI(base.TestCase):
 
-    def setUp(self):
-        super(TestDecisionEngineAPI, self).setUp()
-
     api = rpcapi.DecisionEngineAPI()
 
     def test_get_api_version(self):
@@ -49,3 +46,20 @@ class TestDecisionEngineAPI(base.TestCase):
             self.api.trigger_audit(self.context, audit_uuid)
             mock_cast.assert_called_once_with(
                 self.context, 'trigger_audit', audit_uuid=audit_uuid)
+
+    def test_get_strategy_info(self):
+        with mock.patch.object(om.RPCClient, 'call') as mock_call:
+            self.api.get_strategy_info(self.context, "dummy")
+            mock_call.assert_called_once_with(
+                self.context, 'get_strategy_info', strategy_name="dummy")
+
+    def test_get_data_model_info(self):
+        with mock.patch.object(om.RPCClient, 'call') as mock_call:
+            self.api.get_data_model_info(
+                self.context,
+                data_model_type='compute',
+                audit=None)
+            mock_call.assert_called_once_with(
+                self.context, 'get_data_model_info',
+                data_model_type='compute',
+                audit=None)
