@@ -71,9 +71,9 @@ class TestActionPlanNotification(base.DbTestCase):
         self.assertDictEqual(
             {
                 "watcher_object.namespace": "watcher",
-                "watcher_object.version": "1.0",
+                "watcher_object.version": "1.1",
                 "watcher_object.data": {
-                    "global_efficacy": {},
+                    "global_efficacy": [],
                     "strategy_uuid": "cb3d0b58-4415-4d90-b75b-1e96878730e3",
                     "strategy": {
                         "watcher_object.namespace": "watcher",
@@ -94,8 +94,11 @@ class TestActionPlanNotification(base.DbTestCase):
                     "audit": {
                         "watcher_object.data": {
                             "interval": None,
+                            "next_run_time": None,
+                            "auto_trigger": False,
                             "parameters": {},
                             "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                            "name": "My Audit",
                             "strategy_uuid": None,
                             "goal_uuid": (
                                 "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
@@ -108,7 +111,7 @@ class TestActionPlanNotification(base.DbTestCase):
                         },
                         "watcher_object.name": "TerseAuditPayload",
                         "watcher_object.namespace": "watcher",
-                        "watcher_object.version": "1.0"
+                        "watcher_object.version": "1.2"
                     },
                     "deleted_at": None,
                     "state": "ONGOING",
@@ -145,9 +148,9 @@ class TestActionPlanNotification(base.DbTestCase):
         self.assertDictEqual(
             {
                 "watcher_object.namespace": "watcher",
-                "watcher_object.version": "1.0",
+                "watcher_object.version": "1.1",
                 "watcher_object.data": {
-                    "global_efficacy": {},
+                    "global_efficacy": [],
                     "strategy_uuid": "cb3d0b58-4415-4d90-b75b-1e96878730e3",
                     "strategy": {
                         "watcher_object.namespace": "watcher",
@@ -168,8 +171,11 @@ class TestActionPlanNotification(base.DbTestCase):
                     "audit": {
                         "watcher_object.data": {
                             "interval": None,
+                            "next_run_time": None,
+                            "auto_trigger": False,
                             "parameters": {},
                             "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                            "name": "My Audit",
                             "strategy_uuid": None,
                             "goal_uuid": (
                                 "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
@@ -182,7 +188,7 @@ class TestActionPlanNotification(base.DbTestCase):
                         },
                         "watcher_object.name": "TerseAuditPayload",
                         "watcher_object.namespace": "watcher",
-                        "watcher_object.version": "1.0"
+                        "watcher_object.version": "1.2"
                     },
                     "deleted_at": None,
                     "state": "PENDING",
@@ -211,9 +217,9 @@ class TestActionPlanNotification(base.DbTestCase):
         self.assertDictEqual(
             {
                 "watcher_object.namespace": "watcher",
-                "watcher_object.version": "1.0",
+                "watcher_object.version": "1.1",
                 "watcher_object.data": {
-                    "global_efficacy": {},
+                    "global_efficacy": [],
                     "strategy_uuid": "cb3d0b58-4415-4d90-b75b-1e96878730e3",
                     "strategy": {
                         "watcher_object.namespace": "watcher",
@@ -234,8 +240,11 @@ class TestActionPlanNotification(base.DbTestCase):
                     "audit": {
                         "watcher_object.data": {
                             "interval": None,
+                            "next_run_time": None,
+                            "auto_trigger": False,
                             "parameters": {},
                             "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                            "name": "My Audit",
                             "strategy_uuid": None,
                             "goal_uuid": (
                                 "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
@@ -248,7 +257,7 @@ class TestActionPlanNotification(base.DbTestCase):
                         },
                         "watcher_object.name": "TerseAuditPayload",
                         "watcher_object.namespace": "watcher",
-                        "watcher_object.version": "1.0"
+                        "watcher_object.version": "1.2"
                     },
                     "deleted_at": None,
                     "state": "DELETED",
@@ -287,11 +296,14 @@ class TestActionPlanNotification(base.DbTestCase):
                         "audit": {
                             "watcher_object.namespace": "watcher",
                             "watcher_object.name": "TerseAuditPayload",
-                            "watcher_object.version": "1.0",
+                            "watcher_object.version": "1.2",
                             "watcher_object.data": {
                                 "interval": None,
+                                "next_run_time": None,
+                                "auto_trigger": False,
                                 "parameters": {},
                                 "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                                "name": "My Audit",
                                 "strategy_uuid": None,
                                 "goal_uuid": (
                                     "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
@@ -303,7 +315,7 @@ class TestActionPlanNotification(base.DbTestCase):
                                 "audit_type": "ONESHOT"
                             }
                         },
-                        "global_efficacy": {},
+                        "global_efficacy": [],
                         "state": "ONGOING",
                         "strategy_uuid": (
                             "cb3d0b58-4415-4d90-b75b-1e96878730e3"),
@@ -326,7 +338,7 @@ class TestActionPlanNotification(base.DbTestCase):
                     },
                     "watcher_object.name": "ActionPlanActionPayload",
                     "watcher_object.namespace": "watcher",
-                    "watcher_object.version": "1.0"
+                    "watcher_object.version": "1.1"
                 }
             },
             notification
@@ -373,8 +385,11 @@ class TestActionPlanNotification(base.DbTestCase):
                         "audit": {
                             "watcher_object.data": {
                                 "interval": None,
+                                "next_run_time": None,
+                                "auto_trigger": False,
                                 "parameters": {},
                                 "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                                "name": "My Audit",
                                 "strategy_uuid": None,
                                 "goal_uuid": (
                                     "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
@@ -387,9 +402,9 @@ class TestActionPlanNotification(base.DbTestCase):
                             },
                             "watcher_object.name": "TerseAuditPayload",
                             "watcher_object.namespace": "watcher",
-                            "watcher_object.version": "1.0"
+                            "watcher_object.version": "1.2"
                         },
-                        "global_efficacy": {},
+                        "global_efficacy": [],
                         "state": "ONGOING",
                         "strategy_uuid": (
                             "cb3d0b58-4415-4d90-b75b-1e96878730e3"),
@@ -412,7 +427,170 @@ class TestActionPlanNotification(base.DbTestCase):
                     },
                     "watcher_object.name": "ActionPlanActionPayload",
                     "watcher_object.namespace": "watcher",
-                    "watcher_object.version": "1.0"
+                    "watcher_object.version": "1.1"
+                }
+            },
+            notification
+        )
+
+    def test_send_action_plan_cancel(self):
+        action_plan = utils.create_test_action_plan(
+            mock.Mock(), state=objects.action_plan.State.ONGOING,
+            audit_id=self.audit.id, strategy_id=self.strategy.id,
+            audit=self.audit, strategy=self.strategy)
+        notifications.action_plan.send_cancel_notification(
+            mock.MagicMock(), action_plan, host='node0',
+            action='cancel', phase='start')
+
+        # The 1st notification is because we created the audit object.
+        # The 2nd notification is because we created the action plan object.
+        self.assertEqual(3, self.m_notifier.info.call_count)
+        notification = self.m_notifier.info.call_args[1]
+        self.assertEqual("infra-optim:node0", self.m_notifier.publisher_id)
+        self.assertDictEqual(
+            {
+                "event_type": "action_plan.cancel.start",
+                "payload": {
+                    "watcher_object.data": {
+                        "created_at": "2016-10-18T09:52:05Z",
+                        "deleted_at": None,
+                        "fault": None,
+                        "audit_uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                        "audit": {
+                            "watcher_object.namespace": "watcher",
+                            "watcher_object.name": "TerseAuditPayload",
+                            "watcher_object.version": "1.2",
+                            "watcher_object.data": {
+                                "interval": None,
+                                "next_run_time": None,
+                                "auto_trigger": False,
+                                "parameters": {},
+                                "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                                'name': 'My Audit',
+                                "strategy_uuid": None,
+                                "goal_uuid": (
+                                    "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
+                                "deleted_at": None,
+                                "scope": [],
+                                "state": "PENDING",
+                                "updated_at": None,
+                                "created_at": "2016-10-18T09:52:05Z",
+                                "audit_type": "ONESHOT"
+                            }
+                        },
+                        "global_efficacy": [],
+                        "state": "ONGOING",
+                        "strategy_uuid": (
+                            "cb3d0b58-4415-4d90-b75b-1e96878730e3"),
+                        "strategy": {
+                            "watcher_object.data": {
+                                "created_at": "2016-10-18T09:52:05Z",
+                                "deleted_at": None,
+                                "display_name": "test strategy",
+                                "name": "TEST",
+                                "parameters_spec": {},
+                                "updated_at": None,
+                                "uuid": "cb3d0b58-4415-4d90-b75b-1e96878730e3"
+                            },
+                            "watcher_object.name": "StrategyPayload",
+                            "watcher_object.namespace": "watcher",
+                            "watcher_object.version": "1.0"
+                        },
+                        "updated_at": None,
+                        "uuid": "76be87bd-3422-43f9-93a0-e85a577e3061"
+                    },
+                    "watcher_object.name": "ActionPlanCancelPayload",
+                    "watcher_object.namespace": "watcher",
+                    "watcher_object.version": "1.1"
+                }
+            },
+            notification
+        )
+
+    def test_send_action_plan_cancel_with_error(self):
+        action_plan = utils.create_test_action_plan(
+            mock.Mock(), state=objects.action_plan.State.ONGOING,
+            audit_id=self.audit.id, strategy_id=self.strategy.id,
+            audit=self.audit, strategy=self.strategy)
+
+        try:
+            # This is to load the exception in sys.exc_info()
+            raise exception.WatcherException("TEST")
+        except exception.WatcherException:
+            notifications.action_plan.send_cancel_notification(
+                mock.MagicMock(), action_plan, host='node0',
+                action='cancel', priority='error', phase='error')
+
+        self.assertEqual(1, self.m_notifier.error.call_count)
+        notification = self.m_notifier.error.call_args[1]
+        self.assertEqual("infra-optim:node0", self.m_notifier.publisher_id)
+        self.assertDictEqual(
+            {
+                "event_type": "action_plan.cancel.error",
+                "payload": {
+                    "watcher_object.data": {
+                        "created_at": "2016-10-18T09:52:05Z",
+                        "deleted_at": None,
+                        "fault": {
+                            "watcher_object.data": {
+                                "exception": "WatcherException",
+                                "exception_message": "TEST",
+                                "function_name": (
+                                    "test_send_action_plan_cancel_with_error"),
+                                "module_name": "watcher.tests.notifications."
+                                               "test_action_plan_notification"
+                            },
+                            "watcher_object.name": "ExceptionPayload",
+                            "watcher_object.namespace": "watcher",
+                            "watcher_object.version": "1.0"
+                        },
+                        "audit_uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                        "audit": {
+                            "watcher_object.data": {
+                                "interval": None,
+                                "next_run_time": None,
+                                "auto_trigger": False,
+                                "parameters": {},
+                                "uuid": "10a47dd1-4874-4298-91cf-eff046dbdb8d",
+                                'name': 'My Audit',
+                                "strategy_uuid": None,
+                                "goal_uuid": (
+                                    "f7ad87ae-4298-91cf-93a0-f35a852e3652"),
+                                "deleted_at": None,
+                                "scope": [],
+                                "state": "PENDING",
+                                "updated_at": None,
+                                "created_at": "2016-10-18T09:52:05Z",
+                                "audit_type": "ONESHOT"
+                            },
+                            "watcher_object.name": "TerseAuditPayload",
+                            "watcher_object.namespace": "watcher",
+                            "watcher_object.version": "1.2"
+                        },
+                        "global_efficacy": [],
+                        "state": "ONGOING",
+                        "strategy_uuid": (
+                            "cb3d0b58-4415-4d90-b75b-1e96878730e3"),
+                        "strategy": {
+                            "watcher_object.data": {
+                                "created_at": "2016-10-18T09:52:05Z",
+                                "deleted_at": None,
+                                "display_name": "test strategy",
+                                "name": "TEST",
+                                "parameters_spec": {},
+                                "updated_at": None,
+                                "uuid": "cb3d0b58-4415-4d90-b75b-1e96878730e3"
+                            },
+                            "watcher_object.name": "StrategyPayload",
+                            "watcher_object.namespace": "watcher",
+                            "watcher_object.version": "1.0"
+                        },
+                        "updated_at": None,
+                        "uuid": "76be87bd-3422-43f9-93a0-e85a577e3061"
+                    },
+                    "watcher_object.name": "ActionPlanCancelPayload",
+                    "watcher_object.namespace": "watcher",
+                    "watcher_object.version": "1.1"
                 }
             },
             notification
